function varargout = obrEDT(varargin)
% OBREDT M-file for obrEDT.fig
%      OBREDT, by itself, creates a new OBREDT or raises the existing
%      singleton*.
%
%      H = OBREDT returns the handle to a new OBREDT or the handle to
%      the existing singleton*.
%
%      OBREDT('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in OBREDT.M with the given input arguments.
%
%      OBREDT('Property','Value',...) creates a new OBREDT or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before obrEDT_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to obrEDT_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help obrEDT

% Last Modified by GUIDE v2.5 15-May-2011 11:24:22

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @obrEDT_OpeningFcn, ...
                   'gui_OutputFcn',  @obrEDT_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before obrEDT is made visible.
function obrEDT_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to obrEDT (see VARARGIN)

% Choose default command line output for obrEDT
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

guidata(hObject, handles);
global ir;
global n;
global Fs;
 

   
    [EDT,x,E] = reverberb_EDT(ir,Fs);
 
axes(handles.axes1); 
        
         plot(x,E,'LineWidth',1.5)
         title('Early Decay Time');
         grid on 
        
        xlabel ('t [s]'), ylabel('EDT [dB]');    


% UIWAIT makes obrEDT wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = obrEDT_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
